@@ -81,13 +81,8 @@ struct NautilusDesktopIconViewDetails
 };
 
 static void     default_zoom_level_changed                        (gpointer                user_data);
-static gboolean real_supports_auto_layout                         (NautilusIconView             *view);
-static gboolean real_supports_scaling	                          (NautilusIconView             *view);
-static gboolean real_supports_keep_aligned                        (NautilusIconView             *view);
-static gboolean real_supports_labels_beside_icons                 (NautilusIconView             *view);
 static void     real_merge_menus                                  (NautilusView        *view);
 static void     real_update_menus                                 (NautilusView        *view);
-static gboolean real_supports_zooming                             (NautilusView        *view);
 static void     nautilus_desktop_icon_view_update_icon_container_fonts  (NautilusDesktopIconView      *view);
 static void     font_changed_callback                             (gpointer                callback_data);
 
@@ -96,6 +91,8 @@ G_DEFINE_TYPE (NautilusDesktopIconView, nautilus_desktop_icon_view, NAUTILUS_TYP
 static char *desktop_directory;
 static time_t desktop_dir_modify_time;
 
+#define get_icon_container(w) nautilus_icon_view_get_icon_container(NAUTILUS_ICON_VIEW (w))
+
 static void
 desktop_directory_changed_callback (gpointer callback_data)
 {
@@ -103,15 +100,6 @@ desktop_directory_changed_callback (gpointer callback_data)
 	desktop_directory = nautilus_get_desktop_directory ();
 }
 
-static NautilusIconContainer *
-get_icon_container (NautilusDesktopIconView *icon_view)
-{
-	g_return_val_if_fail (NAUTILUS_IS_DESKTOP_ICON_VIEW (icon_view), NULL);
-	g_return_val_if_fail (NAUTILUS_IS_ICON_CONTAINER (gtk_bin_get_child (GTK_BIN (icon_view))), NULL);
-
-	return NAUTILUS_ICON_CONTAINER (gtk_bin_get_child (GTK_BIN (icon_view)));
-}
-
 static void
 icon_container_set_workarea (NautilusIconContainer *icon_container,
 			     GdkScreen             *screen,
@@ -321,24 +309,16 @@ static void
 nautilus_desktop_icon_view_class_init (NautilusDesktopIconViewClass *class)
 {
 	NautilusViewClass *vclass;
-	NautilusIconViewClass *iclass;
 
 	vclass = NAUTILUS_VIEW_CLASS (class);
-	iclass = NAUTILUS_ICON_VIEW_CLASS (class);
 
 	G_OBJECT_CLASS (class)->dispose = nautilus_desktop_icon_view_dispose;
 
 	vclass->begin_loading = real_begin_loading;
 	vclass->merge_menus = real_merge_menus;
 	vclass->update_menus = real_update_menus;
-	vclass->supports_zooming = real_supports_zooming;
 	vclass->get_view_id = real_get_id;
 
-	iclass->supports_auto_layout = real_supports_auto_layout;
-	iclass->supports_scaling = real_supports_scaling;
-	iclass->supports_keep_aligned = real_supports_keep_aligned;
-	iclass->supports_labels_beside_icons = real_supports_labels_beside_icons;
-
 	g_type_class_add_private (class, sizeof (NautilusDesktopIconViewDetails));
 }
 
@@ -822,43 +802,6 @@ real_merge_menus (NautilusView *view)
 		gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 }
 
-static gboolean
-real_supports_auto_layout (NautilusIconView *view)
-{
-	/* Can't use auto-layout on the desktop, because doing so
-	 * would cause all sorts of complications involving the
-	 * fixed-size window.
-	 */
-	return FALSE;
-}
-
-static gboolean
-real_supports_scaling (NautilusIconView *view)
-{
-	return TRUE;
-}
-
-static gboolean
-real_supports_keep_aligned (NautilusIconView *view)
-{
-	return TRUE;
-}
-
-static gboolean
-real_supports_labels_beside_icons (NautilusIconView *view)
-{
-	return FALSE;
-}
-
-static gboolean
-real_supports_zooming (NautilusView *view)
-{
-	/* Can't zoom on the desktop, because doing so would cause all
-	 * sorts of complications involving the fixed-size window.
-	 */
-	return FALSE;
-}
-
 static NautilusView *
 nautilus_desktop_icon_view_create (NautilusWindowSlot *slot)
 {
@@ -866,6 +809,12 @@ nautilus_desktop_icon_view_create (NautilusWindowSlot *slot)
 
 	view = g_object_new (NAUTILUS_TYPE_DESKTOP_ICON_VIEW,
 			     "window-slot", slot,
+			     "show-floating-bar", FALSE,
+			     "supports-zooming", FALSE,
+			     "supports-auto-layout", FALSE,
+			     "supports-scaling", TRUE,
+			     "supports-keep-aligned", TRUE,
+			     "supports-labels-beside-icons", FALSE,
 			     NULL);
 	return NAUTILUS_VIEW (view);
 }
