@@ -28,6 +28,7 @@
 #include <config.h>
 #include "nautilus-list-view.h"
 
+#include "gedit-overlay.h"
 #include "nautilus-list-model.h"
 #include "nautilus-error-reporting.h"
 #include "nautilus-view-dnd.h"
@@ -259,9 +260,7 @@ activate_selected_items (NautilusListView *view)
 	
 	nautilus_view_activate_files (NAUTILUS_VIEW (view),
 				      file_list,
-				      NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-				      0,
-				      TRUE);
+				      0, TRUE);
 	nautilus_file_list_free (file_list);
 
 }
@@ -274,13 +273,18 @@ activate_selected_items_alternate (NautilusListView *view,
 	GList *file_list;
 	NautilusWindowOpenFlags flags;
 
-	flags = NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND;
+	flags = 0;
 
-	if (open_in_tab) {
-		flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-        } else {
-		flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
-        }
+	if (g_settings_get_boolean (nautilus_preferences,
+				    NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
+		if (open_in_tab) {
+			flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+		} else {
+			flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
+		}
+	} else {
+		flags |= NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND;
+	}
 
 	if (file != NULL) {
 		nautilus_file_ref (file);
@@ -290,7 +294,6 @@ activate_selected_items_alternate (NautilusListView *view,
 	}
 	nautilus_view_activate_files (NAUTILUS_VIEW (view),
 				      file_list,
-				      NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
 				      flags,
 				      TRUE);
 	nautilus_file_list_free (file_list);
@@ -610,6 +613,13 @@ do_popup_menu (GtkWidget *widget, NautilusListView *view, GdkEventButton *event)
 	}
 }
 
+static void
+row_activated_callback (GtkTreeView *treeview, GtkTreePath *path, 
+			GtkTreeViewColumn *column, NautilusListView *view)
+{
+	activate_selected_items (view);
+}
+
 static gboolean
 button_press_callback (GtkWidget *widget, GdkEventButton *event, gpointer callback_data)
 {
@@ -766,7 +776,15 @@ button_press_callback (GtkWidget *widget, GdkEventButton *event, gpointer callba
 			}
 		
 			if (call_parent) {
+				g_signal_handlers_block_by_func (tree_view,
+								 row_activated_callback,
+								 view);
+
 				tree_view_class->button_press_event (widget, event);
+
+				g_signal_handlers_unblock_by_func (tree_view,
+								   row_activated_callback,
+								   view);
 			} else if (gtk_tree_selection_path_is_selected (selection, path)) {
 				gtk_widget_grab_focus (widget);
 			}
@@ -957,13 +975,6 @@ row_collapsed_callback (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *p
 			       unload_data);
 }
 
-static void
-row_activated_callback (GtkTreeView *treeview, GtkTreePath *path, 
-			GtkTreeViewColumn *column, NautilusListView *view)
-{
-	activate_selected_items (view);
-}
-
 static void
 subdirectory_unloaded_callback (NautilusListModel *model,
 				NautilusDirectory *directory,
@@ -1530,6 +1541,7 @@ create_and_set_up_tree_view (NautilusListView *view)
 {
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
+	GtkWidget *overlay;
 	GtkBindingSet *binding_set;
 	AtkObject *atk_obj;
 	GList *nautilus_columns;
@@ -1712,8 +1724,11 @@ create_and_set_up_tree_view (NautilusListView *view)
 				default_visible_columns);
 
 	gtk_widget_show (GTK_WIDGET (view->details->tree_view));
-	gtk_container_add (GTK_CONTAINER (view), GTK_WIDGET (view->details->tree_view));
 
+	overlay = gedit_overlay_new (GTK_WIDGET (view->details->tree_view));
+	gtk_widget_show (overlay);
+
+	nautilus_view_setup_overlay (NAUTILUS_VIEW (view), overlay);
 
         atk_obj = gtk_widget_get_accessible (GTK_WIDGET (view->details->tree_view));
         atk_object_set_name (atk_obj, _("List View"));
