@@ -38,19 +38,19 @@
 #include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
 #include <libnautilus-private/nautilus-icon-names.h>
-#include <libnautilus-private/nautilus-window-info.h>
-#include <libnautilus-private/nautilus-window-slot-info.h>
 
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-glib-extensions.h>
+#include <eel/eel-graphic-effects.h>
 #include <eel/eel-string.h>
 #include <eel/eel-stock-dialogs.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
 
+#include "nautilus-application.h"
 #include "nautilus-bookmark-list.h"
 #include "nautilus-places-sidebar.h"
 #include "nautilus-window.h"
+#include "nautilus-window-slot.h"
 
 #define DEBUG_FLAG NAUTILUS_DEBUG_PLACES
 #include <libnautilus-private/nautilus-debug.h>
@@ -68,7 +68,7 @@ typedef struct {
 	char 	           *uri;
 	GtkListStore       *store;
 	GtkTreeModel       *filter_model;
-	NautilusWindowInfo *window;
+	NautilusWindow *window;
 	NautilusBookmarkList *bookmarks;
 	GVolumeMonitor *volume_monitor;
 
@@ -90,14 +90,13 @@ typedef struct {
 	GtkWidget *popup_menu_unmount_item;
 	GtkWidget *popup_menu_eject_item;
 	GtkWidget *popup_menu_rescan_item;
-	GtkWidget *popup_menu_format_item;
 	GtkWidget *popup_menu_empty_trash_item;
 	GtkWidget *popup_menu_start_item;
 	GtkWidget *popup_menu_stop_item;
 
 	/* volume mounting - delayed open process */
 	gboolean mounting;
-	NautilusWindowSlotInfo *go_to_after_mount_slot;
+	NautilusWindowSlot *go_to_after_mount_slot;
 	NautilusWindowOpenFlags go_to_after_mount_flags;
 
 	GtkTreePath *eject_highlight_path;
@@ -213,25 +212,36 @@ static GtkTreeModel *nautilus_shortcuts_model_filter_new (NautilusPlacesSidebar
 G_DEFINE_TYPE (NautilusPlacesSidebar, nautilus_places_sidebar, GTK_TYPE_SCROLLED_WINDOW);
 
 static GdkPixbuf *
-get_eject_icon (gboolean highlighted)
+get_eject_icon (NautilusPlacesSidebar *sidebar,
+		gboolean highlighted)
 {
 	GdkPixbuf *eject;
-	NautilusIconInfo *eject_icon_info;
+	GtkIconInfo *icon_info;
+	GIcon *icon;
 	int icon_size;
+	GtkIconTheme *icon_theme;
+	GtkStyleContext *style;
 
-	icon_size = nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU);
+	icon_theme = gtk_icon_theme_get_default ();
+	icon_size = nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_SMALL_TOOLBAR);
+	icon = g_themed_icon_new_with_default_fallbacks ("media-eject-symbolic");
+	icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon, icon_size, 0);
 
-	eject_icon_info = nautilus_icon_info_lookup_from_name ("media-eject", icon_size);
-	eject = nautilus_icon_info_get_pixbuf_at_size (eject_icon_info, icon_size);
+	style = gtk_widget_get_style_context (GTK_WIDGET (sidebar));
+	eject = gtk_icon_info_load_symbolic_for_context (icon_info,
+							 style,
+							 NULL,
+							 NULL);
 
 	if (highlighted) {
 		GdkPixbuf *high;
-		high = eel_gdk_pixbuf_render (eject, 1, 255, 255, 0, 0);
+		high = eel_create_spotlight_pixbuf (eject);
 		g_object_unref (eject);
 		eject = high;
 	}
 
-	g_object_unref (eject_icon_info);
+	g_object_unref (icon);
+	gtk_icon_info_free (icon_info);
 
 	return eject;
 }
@@ -355,7 +365,7 @@ add_place (NautilusPlacesSidebar *sidebar,
 	}
 
 	if (show_eject_button) {
-		eject = get_eject_icon (FALSE);
+		eject = get_eject_icon (sidebar, FALSE);
 	} else {
 		eject = NULL;
 	}
@@ -432,10 +442,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 	GVolume *volume;
 	int bookmark_count, index;
 	char *location, *mount_uri, *name, *desktop_path, *last_uri;
-	const gchar *path;
+	const gchar *path, *bookmark_name;
 	GIcon *icon;
 	GFile *root;
-	NautilusWindowSlotInfo *slot;
+	NautilusWindowSlot *slot;
 	char *tooltip;
 	GList *network_mounts;
 	NautilusFile *file;
@@ -455,8 +465,8 @@ update_places (NautilusPlacesSidebar *sidebar)
 	sidebar->devices_header_added = FALSE;
 	sidebar->bookmarks_header_added = FALSE;
 
-	slot = nautilus_window_info_get_active_slot (sidebar->window);
-	location = nautilus_window_slot_info_get_current_location (slot);
+	slot = nautilus_window_get_active_slot (sidebar->window);
+	location = nautilus_window_slot_get_current_uri (slot);
 
 	volume_monitor = sidebar->volume_monitor;
 
@@ -607,20 +617,20 @@ update_places (NautilusPlacesSidebar *sidebar)
 			continue;
 		}
 
-		name = nautilus_bookmark_get_name (bookmark);
+		bookmark_name = nautilus_bookmark_get_name (bookmark);
 		icon = nautilus_bookmark_get_icon (bookmark);
 		mount_uri = nautilus_bookmark_get_uri (bookmark);
 		tooltip = g_file_get_parse_name (root);
 
 		last_iter = add_place (sidebar, PLACES_BOOKMARK,
 				       SECTION_BOOKMARKS,
-				       name, icon, mount_uri,
+				       bookmark_name, icon, mount_uri,
 				       NULL, NULL, NULL, index,
 				       tooltip);
 		compare_for_selection (sidebar,
 				       location, mount_uri, last_uri,
 				       &last_iter, &select_path);
-		g_free (name);
+
 		g_object_unref (root);
 		g_object_unref (icon);
 		g_free (mount_uri);
@@ -649,20 +659,24 @@ update_places (NautilusPlacesSidebar *sidebar)
 		g_free (mount_uri);
 	}
 
-	/* desktop */
-	mount_uri = g_filename_to_uri (desktop_path, NULL, NULL);
-	icon = g_themed_icon_new (NAUTILUS_ICON_DESKTOP);
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_COMPUTER,
-			       _("Desktop"), icon,
-			       mount_uri, NULL, NULL, NULL, 0,
-			       _("Open the contents of your desktop in a folder"));
-	g_object_unref (icon);
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
-	g_free (mount_uri);
-	g_free (desktop_path);
+
+	if (g_settings_get_boolean (gnome_background_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP) &&
+	    !g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
+		/* desktop */
+		mount_uri = g_filename_to_uri (desktop_path, NULL, NULL);
+		icon = g_themed_icon_new (NAUTILUS_ICON_DESKTOP);
+		last_iter = add_place (sidebar, PLACES_BUILT_IN,
+				       SECTION_COMPUTER,
+				       _("Desktop"), icon,
+				       mount_uri, NULL, NULL, NULL, 0,
+				       _("Open the contents of your desktop in a folder"));
+		g_object_unref (icon);
+		compare_for_selection (sidebar,
+				       location, mount_uri, last_uri,
+				       &last_iter, &select_path);
+		g_free (mount_uri);
+		g_free (desktop_path);
+	}
 
 	/* file system root */
  	mount_uri = "file:///"; /* No need to strdup */
@@ -991,17 +1005,17 @@ clicked_eject_button (NautilusPlacesSidebar *sidebar,
 }
 
 static void
-desktop_location_changed_callback (gpointer user_data)
+desktop_setting_changed_callback (gpointer user_data)
 {
 	NautilusPlacesSidebar *sidebar;
-	
+
 	sidebar = NAUTILUS_PLACES_SIDEBAR (user_data);
 
 	update_places (sidebar);
 }
 
 static void
-loading_uri_callback (NautilusWindowInfo *window,
+loading_uri_callback (NautilusWindow *window,
 		      char *location,
 		      NautilusPlacesSidebar *sidebar)
 {
@@ -1261,11 +1275,10 @@ bookmarks_drop_uris (NautilusPlacesSidebar *sidebar,
 {
 	NautilusBookmark *bookmark;
 	NautilusFile *file;
-	char *uri, *name;
+	char *uri;
 	char **uris;
 	int i;
 	GFile *location;
-	GIcon *icon;
 	
 	uris = gtk_selection_data_get_uris (selection_data);
 	if (!uris)
@@ -1284,9 +1297,7 @@ bookmarks_drop_uris (NautilusPlacesSidebar *sidebar,
 		location = g_file_new_for_uri (uri);
 		nautilus_file_unref (file);
 
-		name = nautilus_compute_title_for_location (location);
-		icon = g_themed_icon_new (NAUTILUS_ICON_FOLDER);
-		bookmark = nautilus_bookmark_new (location, name, TRUE, icon);
+		bookmark = nautilus_bookmark_new (location, NULL, NULL);
 
 		if (!nautilus_bookmark_list_contains (sidebar->bookmarks, bookmark)) {
 			nautilus_bookmark_list_insert_item (sidebar->bookmarks, bookmark, position++);
@@ -1294,8 +1305,6 @@ bookmarks_drop_uris (NautilusPlacesSidebar *sidebar,
 
 		g_object_unref (location);
 		g_object_unref (bookmark);
-		g_object_unref (icon);
-		g_free (name);
 		g_free (uri);
 	}
 
@@ -1549,7 +1558,6 @@ bookmarks_popup_menu_detach_cb (GtkWidget *attach_widget,
 	sidebar->popup_menu_unmount_item = NULL;
 	sidebar->popup_menu_eject_item = NULL;
 	sidebar->popup_menu_rescan_item = NULL;
-	sidebar->popup_menu_format_item = NULL;
 	sidebar->popup_menu_start_item = NULL;
 	sidebar->popup_menu_stop_item = NULL;
 	sidebar->popup_menu_empty_trash_item = NULL;
@@ -1586,12 +1594,10 @@ check_visibility (GMount           *mount,
 		  gboolean         *show_unmount,
 		  gboolean         *show_eject,
 		  gboolean         *show_rescan,
-		  gboolean         *show_format,
 		  gboolean         *show_start,
 		  gboolean         *show_stop)
 {
 	*show_mount = FALSE;
-	*show_format = FALSE;
 	*show_rescan = FALSE;
 	*show_start = FALSE;
 	*show_stop = FALSE;
@@ -1629,7 +1635,6 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	gboolean show_unmount;
 	gboolean show_eject;
 	gboolean show_rescan;
-	gboolean show_format;
 	gboolean show_start;
 	gboolean show_stop;
 	gboolean show_empty_trash;
@@ -1658,7 +1663,7 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	gtk_widget_set_sensitive (sidebar->popup_menu_empty_trash_item, !nautilus_trash_monitor_is_empty ());
 
  	check_visibility (mount, volume, drive,
- 			  &show_mount, &show_unmount, &show_eject, &show_rescan, &show_format, &show_start, &show_stop);
+ 			  &show_mount, &show_unmount, &show_eject, &show_rescan, &show_start, &show_stop);
 
 	/* We actually want both eject and unmount since eject will unmount all volumes. 
 	 * TODO: hide unmount if the drive only has a single mountable volume 
@@ -1668,12 +1673,11 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 			   (!strcmp (uri, "trash:///"));
 
 	gtk_widget_set_visible (sidebar->popup_menu_separator_item,
-		      show_mount || show_unmount || show_eject || show_format || show_empty_trash);
+		      show_mount || show_unmount || show_eject || show_empty_trash);
 	gtk_widget_set_visible (sidebar->popup_menu_mount_item, show_mount);
 	gtk_widget_set_visible (sidebar->popup_menu_unmount_item, show_unmount);
 	gtk_widget_set_visible (sidebar->popup_menu_eject_item, show_eject);
 	gtk_widget_set_visible (sidebar->popup_menu_rescan_item, show_rescan);
-	gtk_widget_set_visible (sidebar->popup_menu_format_item, show_format);
 	gtk_widget_set_visible (sidebar->popup_menu_start_item, show_start);
 	gtk_widget_set_visible (sidebar->popup_menu_stop_item, show_stop);
 	gtk_widget_set_visible (sidebar->popup_menu_empty_trash_item, show_empty_trash);
@@ -1739,17 +1743,20 @@ volume_mounted_cb (GVolume *volume,
 
 		if (sidebar->go_to_after_mount_slot != NULL) {
 			if ((sidebar->go_to_after_mount_flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) == 0) {
-				nautilus_window_slot_info_open_location (sidebar->go_to_after_mount_slot, location,
-									 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-									 sidebar->go_to_after_mount_flags, NULL);
+				nautilus_window_slot_open_location (sidebar->go_to_after_mount_slot, location,
+								    sidebar->go_to_after_mount_flags, NULL);
 			} else {
-				NautilusWindow *cur, *new;
-				
+				NautilusApplication *app;
+				NautilusWindow *new, *cur;
+
 				cur = NAUTILUS_WINDOW (sidebar->window);
-				new = nautilus_application_create_navigation_window (cur->application,
-										     NULL,
-										     gtk_window_get_screen (GTK_WINDOW (cur)));
+				app = nautilus_application_dup_singleton ();
+				new = nautilus_application_create_window (app,
+									  NULL,
+									  gtk_window_get_screen (GTK_WINDOW (cur)));
 				nautilus_window_go_to (new, location);
+
+				g_object_unref (app);
 			}
 		}
 
@@ -1791,7 +1798,7 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 			GtkTreePath	      *path,
 			NautilusWindowOpenFlags	      flags)
 {
-	NautilusWindowSlotInfo *slot;
+	NautilusWindowSlot *slot;
 	GtkTreeIter iter;
 	GFile *location;
 	char *uri;
@@ -1812,18 +1819,21 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 		location = g_file_new_for_uri (uri);
 		/* Navigate to the clicked location */
 		if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) == 0) {
-			slot = nautilus_window_info_get_active_slot (sidebar->window);
-			nautilus_window_slot_info_open_location (slot, location,
-								 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-								 flags, NULL);
+			slot = nautilus_window_get_active_slot (sidebar->window);
+			nautilus_window_slot_open_location (slot, location,
+							    flags, NULL);
 		} else {
 			NautilusWindow *cur, *new;
+			NautilusApplication *app;
 			
 			cur = NAUTILUS_WINDOW (sidebar->window);
-			new = nautilus_application_create_navigation_window (cur->application,
-									     NULL,
-									     gtk_window_get_screen (GTK_WINDOW (cur)));
+			app = nautilus_application_dup_singleton ();
+			new = nautilus_application_create_window (app,
+								  NULL,
+								  gtk_window_get_screen (GTK_WINDOW (cur)));
 			nautilus_window_go_to (new, location);
+
+			g_object_unref (app);
 		}
 		g_object_unref (location);
 		g_free (uri);
@@ -1843,7 +1853,7 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 
 			g_assert (sidebar->go_to_after_mount_slot == NULL);
 
-			slot = nautilus_window_info_get_active_slot (sidebar->window);
+			slot = nautilus_window_get_active_slot (sidebar->window);
 			sidebar->go_to_after_mount_slot = slot;
 			eel_add_weak_pointer (&(sidebar->go_to_after_mount_slot));
 
@@ -1995,7 +2005,7 @@ unmount_done (gpointer data)
 	NautilusWindow *window;
 
 	window = data;
-	nautilus_window_info_set_initiated_unmount (window, FALSE);
+	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 }
 
@@ -2004,7 +2014,7 @@ do_unmount (GMount *mount,
 	    NautilusPlacesSidebar *sidebar)
 {
 	if (mount != NULL) {
-		nautilus_window_info_set_initiated_unmount (sidebar->window, TRUE);
+		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		nautilus_file_operations_unmount_mount_full (NULL, mount, FALSE, TRUE,
 							     unmount_done,
 							     g_object_ref (sidebar->window));
@@ -2049,7 +2059,7 @@ drive_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_info_set_initiated_unmount (window, FALSE);
+	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2078,7 +2088,7 @@ volume_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_info_set_initiated_unmount (window, FALSE);
+	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2107,7 +2117,7 @@ mount_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_info_set_initiated_unmount (window, FALSE);
+	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2135,15 +2145,15 @@ do_eject (GMount *mount,
 
 	mount_op = gtk_mount_operation_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar))));
 	if (mount != NULL) {
-		nautilus_window_info_set_initiated_unmount (sidebar->window, TRUE);
+		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_mount_eject_with_operation (mount, 0, mount_op, NULL, mount_eject_cb,
 					      g_object_ref (sidebar->window));
 	} else if (volume != NULL) {
-		nautilus_window_info_set_initiated_unmount (sidebar->window, TRUE);
+		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_volume_eject_with_operation (volume, 0, mount_op, NULL, volume_eject_cb,
 					      g_object_ref (sidebar->window));
 	} else if (drive != NULL) {
-		nautilus_window_info_set_initiated_unmount (sidebar->window, TRUE);
+		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_drive_eject_with_operation (drive, 0, mount_op, NULL, drive_eject_cb,
 					      g_object_ref (sidebar->window));
 	}
@@ -2289,13 +2299,6 @@ rescan_shortcut_cb (GtkMenuItem           *item,
 	g_object_unref (drive);
 }
 
-static void
-format_shortcut_cb (GtkMenuItem           *item,
-		    NautilusPlacesSidebar *sidebar)
-{
-	g_spawn_command_line_async ("gfloppy", NULL);
-}
-
 static void
 drive_start_cb (GObject      *source_object,
 		GAsyncResult *res,
@@ -2358,7 +2361,7 @@ drive_stop_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_info_set_initiated_unmount (window, FALSE);
+	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2395,7 +2398,7 @@ stop_shortcut_cb (GtkMenuItem           *item,
 		GMountOperation *mount_op;
 
 		mount_op = gtk_mount_operation_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar))));
-		nautilus_window_info_set_initiated_unmount (sidebar->window, TRUE);
+		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_drive_stop (drive, G_MOUNT_UNMOUNT_NONE, mount_op, NULL, drive_stop_cb,
 			      g_object_ref (sidebar->window));
 		g_object_unref (mount_op);
@@ -2420,6 +2423,30 @@ bookmarks_key_press_event_cb (GtkWidget             *widget,
 
   modifiers = gtk_accelerator_get_default_mod_mask ();
 
+  if ((event->keyval == GDK_KEY_Return ||
+       event->keyval == GDK_KEY_KP_Enter ||
+       event->keyval == GDK_KEY_ISO_Enter ||
+       event->keyval == GDK_KEY_space)) {
+
+      GtkTreeModel *model;
+      GtkTreePath *path;
+      NautilusWindowOpenFlags flags = 0;
+
+      if ((event->state & modifiers) == GDK_SHIFT_MASK) {
+          flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+      } else if ((event->state & modifiers) == GDK_CONTROL_MASK) {
+          flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
+      }
+
+      model = gtk_tree_view_get_model (sidebar->tree_view);
+      gtk_tree_view_get_cursor (sidebar->tree_view, &path, NULL);
+
+      open_selected_bookmark (sidebar, model, path, flags);
+
+      gtk_tree_path_free (path);
+      return TRUE;
+  }
+
   if (event->keyval == GDK_KEY_Down &&
       (event->state & modifiers) == GDK_MOD1_MASK) {
       return eject_or_unmount_selection (sidebar);
@@ -2528,13 +2555,6 @@ bookmarks_build_popup_menu (NautilusPlacesSidebar *sidebar)
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (sidebar->popup_menu), item);
 
-	item = gtk_menu_item_new_with_mnemonic (_("_Format"));
-	sidebar->popup_menu_format_item = item;
-	g_signal_connect (item, "activate",
-		    G_CALLBACK (format_shortcut_cb), sidebar);
-	gtk_widget_show (item);
-	gtk_menu_shell_append (GTK_MENU_SHELL (sidebar->popup_menu), item);
-
 	item = gtk_menu_item_new_with_mnemonic (_("_Start"));
 	sidebar->popup_menu_start_item = item;
 	g_signal_connect (item, "activate",
@@ -2674,7 +2694,7 @@ update_eject_buttons (NautilusPlacesSidebar *sidebar,
 
 			gtk_list_store_set (sidebar->store,
 					    &iter,
-					    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (FALSE),
+					    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (sidebar, FALSE),
 					    -1);
 			gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
 
@@ -2696,7 +2716,7 @@ update_eject_buttons (NautilusPlacesSidebar *sidebar,
 					 path);
 		gtk_list_store_set (sidebar->store,
 				    &iter,
-				    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (TRUE),
+				    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (sidebar, TRUE),
 				    -1);
 		gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
 
@@ -2710,9 +2730,7 @@ bookmarks_motion_event_cb (GtkWidget             *widget,
 			   NautilusPlacesSidebar *sidebar)
 {
 	GtkTreePath *path;
-	GtkTreeModel *model;
 
-	model = GTK_TREE_MODEL (sidebar->filter_model);
 	path = NULL;
 
 	if (over_eject_button (sidebar, event->x, event->y, &path)) {
@@ -2793,7 +2811,7 @@ bookmarks_edited (GtkCellRenderer       *cell,
 	bookmark = nautilus_bookmark_list_item_at (sidebar->bookmarks, index);
 
 	if (bookmark != NULL) {
-		nautilus_bookmark_set_name (bookmark, new_text);
+		nautilus_bookmark_set_custom_name (bookmark, new_text);
 	}
 }
 
@@ -2848,11 +2866,8 @@ icon_cell_renderer_func (GtkTreeViewColumn *column,
 			 GtkTreeIter *iter,
 			 gpointer user_data)
 {
-	NautilusPlacesSidebar *sidebar;
 	PlaceType type;
 
-	sidebar = user_data;
-
 	gtk_tree_model_get (model, iter,
 			    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 			    -1);
@@ -2938,6 +2953,9 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (sidebar), NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sidebar), GTK_SHADOW_IN);
 
+	gtk_style_context_set_junction_sides (gtk_widget_get_style_context (GTK_WIDGET (sidebar)),
+					      GTK_JUNCTION_RIGHT | GTK_JUNCTION_LEFT);
+
   	/* tree view */
 	tree_view = GTK_TREE_VIEW (gtk_tree_view_new ());
 	gtk_tree_view_set_headers_visible (tree_view, FALSE);
@@ -3115,7 +3133,11 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 							TRUE);
 
 	g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-				  G_CALLBACK(desktop_location_changed_callback),
+				  G_CALLBACK(desktop_setting_changed_callback),
+				  sidebar);
+
+	g_signal_connect_swapped (gnome_background_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+				  G_CALLBACK(desktop_setting_changed_callback),
 				  sidebar);
 
 	g_signal_connect_object (nautilus_trash_monitor_get (),
@@ -3144,25 +3166,19 @@ nautilus_places_sidebar_dispose (GObject *object)
 		sidebar->eject_highlight_path = NULL;
 	}
 
-	if (sidebar->store != NULL) {
-		g_object_unref (sidebar->store);
-		sidebar->store = NULL;
-	}
-
-	if (sidebar->volume_monitor != NULL) {
-		g_object_unref (sidebar->volume_monitor);
-		sidebar->volume_monitor = NULL;
-	}
-
-	if (sidebar->bookmarks != NULL) {
-		g_object_unref (sidebar->bookmarks);
-		sidebar->bookmarks = NULL;
-	}
+	g_clear_object (&sidebar->store);
+	g_clear_object (&sidebar->volume_monitor);
+	g_clear_object (&sidebar->bookmarks);
+	g_clear_object (&sidebar->filter_model);
 
 	eel_remove_weak_pointer (&(sidebar->go_to_after_mount_slot));
 
 	g_signal_handlers_disconnect_by_func (nautilus_preferences,
-					      desktop_location_changed_callback,
+					      desktop_setting_changed_callback,
+					      sidebar);
+
+	g_signal_handlers_disconnect_by_func (gnome_background_preferences,
+					      desktop_setting_changed_callback,
 					      sidebar);
 
 	G_OBJECT_CLASS (nautilus_places_sidebar_parent_class)->dispose (object);
@@ -3178,18 +3194,18 @@ nautilus_places_sidebar_class_init (NautilusPlacesSidebarClass *class)
 
 static void
 nautilus_places_sidebar_set_parent_window (NautilusPlacesSidebar *sidebar,
-					   NautilusWindowInfo *window)
+					   NautilusWindow *window)
 {
-	NautilusWindowSlotInfo *slot;
+	NautilusWindowSlot *slot;
 
 	sidebar->window = window;
 
-	slot = nautilus_window_info_get_active_slot (window);
+	slot = nautilus_window_get_active_slot (window);
 
 	sidebar->bookmarks = nautilus_bookmark_list_new ();
-	sidebar->uri = nautilus_window_slot_info_get_current_location (slot);
+	sidebar->uri = nautilus_window_slot_get_current_uri (slot);
 
-	g_signal_connect_object (sidebar->bookmarks, "contents_changed",
+	g_signal_connect_object (sidebar->bookmarks, "changed",
 				 G_CALLBACK (update_places),
 				 sidebar, G_CONNECT_SWAPPED);
 
@@ -3231,7 +3247,7 @@ nautilus_places_sidebar_style_set (GtkWidget *widget,
 }
 
 GtkWidget *
-nautilus_places_sidebar_new (NautilusWindowInfo *window)
+nautilus_places_sidebar_new (NautilusWindow *window)
 {
 	NautilusPlacesSidebar *sidebar;
 	
