@@ -232,13 +232,6 @@ struct NautilusViewClass {
 						NautilusFile    *a,
 						NautilusFile    *b);
 
-	/* supports_zooming is a function pointer that subclasses may
-	 * override to control whether or not the zooming control and
-	 * menu items should be enabled. The default implementation
-	 * returns TRUE.
-	 */
-	gboolean (* supports_zooming)		(NautilusView *view);
-
 	/* using_manual_layout is a function pointer that subclasses may
 	 * override to control whether or not items can be freely positioned
 	 * on the user-visible area.
@@ -326,7 +319,6 @@ gboolean            nautilus_view_get_loading                      (NautilusView
  */
 void                nautilus_view_activate_files                   (NautilusView        *view,
 								    GList                  *files,
-								    NautilusWindowOpenMode  mode,
 								    NautilusWindowOpenFlags flags,
 								    gboolean                confirm_multiple);
 void                nautilus_view_start_batching_selection_changes (NautilusView  *view);
@@ -410,5 +402,7 @@ void              nautilus_view_update_menus               (NautilusView      *v
 void              nautilus_view_set_is_active              (NautilusView      *view,
 							    gboolean           is_active);
 
+void              nautilus_view_setup_overlay              (NautilusView      *view,
+							    GtkWidget         *overlay);
 
 #endif /* NAUTILUS_VIEW_H */
