@@ -35,11 +35,9 @@
 #include "nautilus-pathbar.h"
 #include "nautilus-window-private.h"
 #include "nautilus-window-slot.h"
-#include "nautilus-navigation-window-slot.h"
 #include "nautilus-trash-bar.h"
+#include "nautilus-view-factory.h"
 #include "nautilus-x-content-bar.h"
-#include "nautilus-zoom-control.h"
-#include "nautilus-navigation-window-pane.h"
 #include <eel/eel-accessibility.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
@@ -57,13 +55,9 @@
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-metadata.h>
-#include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-monitor.h>
 #include <libnautilus-private/nautilus-search-directory.h>
-#include <libnautilus-private/nautilus-view-factory.h>
-#include <libnautilus-private/nautilus-window-info.h>
-#include <libnautilus-private/nautilus-window-slot-info.h>
 
 #define DEBUG_FLAG NAUTILUS_DEBUG_WINDOW
 #include <libnautilus-private/nautilus-debug.h>
@@ -108,28 +102,14 @@ static void load_new_location                         (NautilusWindowSlot
 static void location_has_really_changed               (NautilusWindowSlot         *slot);
 static void update_for_new_location                   (NautilusWindowSlot         *slot);
 
-void
-nautilus_window_report_selection_changed (NautilusWindowInfo *window)
-{
-	if (window->details->temporarily_ignore_view_signals) {
-		return;
-	}
-
-	g_signal_emit_by_name (window, "selection_changed");
-}
-
 /* set_displayed_location:
  */
 static void
 set_displayed_location (NautilusWindowSlot *slot, GFile *location)
 {
-	NautilusWindow *window;
         GFile *bookmark_location;
         gboolean recreate;
-	char *name;
 
-	window = slot->pane->window;
-        
         if (slot->current_location_bookmark == NULL || location == NULL) {
                 recreate = TRUE;
         } else {
@@ -144,10 +124,8 @@ set_displayed_location (NautilusWindowSlot *slot, GFile *location)
 			g_object_unref (slot->last_location_bookmark);
                 }
 		slot->last_location_bookmark = slot->current_location_bookmark;
-		name = g_file_get_basename (location);
 		slot->current_location_bookmark = (location == NULL) ? NULL
-                        : nautilus_bookmark_new (location, name, FALSE, NULL);
-		g_free (name);
+                        : nautilus_bookmark_new (location, NULL, NULL);
         }
 }
 
@@ -180,19 +158,16 @@ check_last_bookmark_location_matches_slot (NautilusWindowSlot *slot)
 }
 
 static void
-handle_go_back (NautilusNavigationWindowSlot *navigation_slot,
+handle_go_back (NautilusWindowSlot *slot,
 		GFile *location)
 {
-	NautilusWindowSlot *slot;
 	guint i;
 	GList *link;
 	NautilusBookmark *bookmark;
 
-	slot = NAUTILUS_WINDOW_SLOT (navigation_slot);
-
 	/* Going back. Move items from the back list to the forward list. */
-	g_assert (g_list_length (navigation_slot->back_list) > slot->location_change_distance);
-	check_bookmark_location_matches (NAUTILUS_BOOKMARK (g_list_nth_data (navigation_slot->back_list,
+	g_assert (g_list_length (slot->back_list) > slot->location_change_distance);
+	check_bookmark_location_matches (NAUTILUS_BOOKMARK (g_list_nth_data (slot->back_list,
 									     slot->location_change_distance)),
 					 location);
 	g_assert (slot->location != NULL);
@@ -202,40 +177,37 @@ handle_go_back (NautilusNavigationWindowSlot *navigation_slot,
 	check_last_bookmark_location_matches_slot (slot);
 
 	/* Use the first bookmark in the history list rather than creating a new one. */
-	navigation_slot->forward_list = g_list_prepend (navigation_slot->forward_list,
-							     slot->last_location_bookmark);
-	g_object_ref (navigation_slot->forward_list->data);
+	slot->forward_list = g_list_prepend (slot->forward_list,
+					     slot->last_location_bookmark);
+	g_object_ref (slot->forward_list->data);
 				
 	/* Move extra links from Back to Forward list */
 	for (i = 0; i < slot->location_change_distance; ++i) {
-		bookmark = NAUTILUS_BOOKMARK (navigation_slot->back_list->data);
-		navigation_slot->back_list =
-			g_list_remove (navigation_slot->back_list, bookmark);
-		navigation_slot->forward_list =
-			g_list_prepend (navigation_slot->forward_list, bookmark);
+		bookmark = NAUTILUS_BOOKMARK (slot->back_list->data);
+		slot->back_list =
+			g_list_remove (slot->back_list, bookmark);
+		slot->forward_list =
+			g_list_prepend (slot->forward_list, bookmark);
 	}
 	
 	/* One bookmark falls out of back/forward lists and becomes viewed location */
-	link = navigation_slot->back_list;
-	navigation_slot->back_list = g_list_remove_link (navigation_slot->back_list, link);
+	link = slot->back_list;
+	slot->back_list = g_list_remove_link (slot->back_list, link);
 	g_object_unref (link->data);
 	g_list_free_1 (link);
 }
 
 static void
-handle_go_forward (NautilusNavigationWindowSlot *navigation_slot,
+handle_go_forward (NautilusWindowSlot *slot,
 		   GFile *location)
 {
-	NautilusWindowSlot *slot;
 	guint i;
 	GList *link;
 	NautilusBookmark *bookmark;
 
-	slot = NAUTILUS_WINDOW_SLOT (navigation_slot);
-
 	/* Going forward. Move items from the forward list to the back list. */
-	g_assert (g_list_length (navigation_slot->forward_list) > slot->location_change_distance);
-	check_bookmark_location_matches (NAUTILUS_BOOKMARK (g_list_nth_data (navigation_slot->forward_list,
+	g_assert (g_list_length (slot->forward_list) > slot->location_change_distance);
+	check_bookmark_location_matches (NAUTILUS_BOOKMARK (g_list_nth_data (slot->forward_list,
 									     slot->location_change_distance)),
 					 location);
 	g_assert (slot->location != NULL);
@@ -244,54 +216,47 @@ handle_go_forward (NautilusNavigationWindowSlot *navigation_slot,
 	check_last_bookmark_location_matches_slot (slot);
 	
 	/* Use the first bookmark in the history list rather than creating a new one. */
-      navigation_slot->back_list = g_list_prepend (navigation_slot->back_list,
-							  slot->last_location_bookmark);
-      g_object_ref (navigation_slot->back_list->data);
+	slot->back_list = g_list_prepend (slot->back_list,
+						     slot->last_location_bookmark);
+	g_object_ref (slot->back_list->data);
 	
 	/* Move extra links from Forward to Back list */
-      for (i = 0; i < slot->location_change_distance; ++i) {
-		bookmark = NAUTILUS_BOOKMARK (navigation_slot->forward_list->data);
-		navigation_slot->forward_list =
-			g_list_remove (navigation_slot->back_list, bookmark);
-		navigation_slot->back_list =
-			g_list_prepend (navigation_slot->forward_list, bookmark);
+	for (i = 0; i < slot->location_change_distance; ++i) {
+		bookmark = NAUTILUS_BOOKMARK (slot->forward_list->data);
+		slot->forward_list =
+			g_list_remove (slot->back_list, bookmark);
+		slot->back_list =
+			g_list_prepend (slot->forward_list, bookmark);
 	}
 	
 	/* One bookmark falls out of back/forward lists and becomes viewed location */
-	link = navigation_slot->forward_list;
-	navigation_slot->forward_list = g_list_remove_link (navigation_slot->forward_list, link);
+	link = slot->forward_list;
+	slot->forward_list = g_list_remove_link (slot->forward_list, link);
 	g_object_unref (link->data);
 	g_list_free_1 (link);
 }
 
 static void
-handle_go_elsewhere (NautilusWindowSlot *slot, GFile *location)
+handle_go_elsewhere (NautilusWindowSlot *slot,
+		     GFile *location)
 {
-#if !NEW_UI_COMPLETE
-	NautilusNavigationWindowSlot *navigation_slot;
-
-	if (NAUTILUS_IS_NAVIGATION_WINDOW_SLOT (slot)) {
-		navigation_slot = NAUTILUS_NAVIGATION_WINDOW_SLOT (slot);
-
-		/* Clobber the entire forward list, and move displayed location to back list */
-		nautilus_navigation_window_slot_clear_forward_list (navigation_slot);
+	/* Clobber the entire forward list, and move displayed location to back list */
+	nautilus_window_slot_clear_forward_list (slot);
 		
-		if (slot->location != NULL) {
-			/* If we're returning to the same uri somehow, don't put this uri on back list. 
-			 * This also avoids a problem where set_displayed_location
-			 * didn't update last_location_bookmark since the uri didn't change.
-			 */
-			if (!g_file_equal (slot->location, location)) {
-				/* Store bookmark for current location in back list, unless there is no current location */
-				check_last_bookmark_location_matches_slot (slot);
-				/* Use the first bookmark in the history list rather than creating a new one. */
-				navigation_slot->back_list = g_list_prepend (navigation_slot->back_list,
-									     slot->last_location_bookmark);
-				g_object_ref (navigation_slot->back_list->data);
-			}
+	if (slot->location != NULL) {
+		/* If we're returning to the same uri somehow, don't put this uri on back list. 
+		 * This also avoids a problem where set_displayed_location
+		 * didn't update last_location_bookmark since the uri didn't change.
+		 */
+		if (!g_file_equal (slot->location, location)) {
+			/* Store bookmark for current location in back list, unless there is no current location */
+			check_last_bookmark_location_matches_slot (slot);
+			/* Use the first bookmark in the history list rather than creating a new one. */
+			slot->back_list = g_list_prepend (slot->back_list,
+							  slot->last_location_bookmark);
+			g_object_ref (slot->back_list->data);
 		}
 	}
-#endif
 }
 
 void
@@ -345,6 +310,9 @@ viewed_file_changed_callback (NautilusFile *file,
                  * file was never seen in the first place.
                  */
                 if (slot->viewed_file_seen) {
+			/* auto-show existing parent. */
+			GFile *go_to_file, *parent, *location;
+
                         /* Detecting a file is gone may happen in the
                          * middle of a pending location change, we
                          * need to cancel it before closing the window
@@ -360,37 +328,30 @@ viewed_file_changed_callback (NautilusFile *file,
                          */
 			end_location_change (slot);
 
-			if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
-				/* auto-show existing parent. */
-				GFile *go_to_file, *parent, *location;
-
-				go_to_file = NULL;
-				location =  nautilus_file_get_location (file);
-				parent = g_file_get_parent (location);
-				g_object_unref (location);
-				if (parent) {
-					go_to_file = nautilus_find_existing_uri_in_hierarchy (parent);
-					g_object_unref (parent);
+			go_to_file = NULL;
+			location =  nautilus_file_get_location (file);
+			parent = g_file_get_parent (location);
+			g_object_unref (location);
+			if (parent) {
+				go_to_file = nautilus_find_existing_uri_in_hierarchy (parent);
+				g_object_unref (parent);
+			}
+				
+			if (go_to_file != NULL) {
+				/* the path bar URI will be set to go_to_uri immediately
+				 * in begin_location_change, but we don't want the
+				 * inexistant children to show up anymore */
+				if (slot == slot->pane->active_slot) {
+					/* multiview-TODO also update NautilusWindowSlot
+					 * [which as of writing doesn't save/store any path bar state]
+					 */
+					nautilus_path_bar_clear_buttons (NAUTILUS_PATH_BAR (slot->pane->path_bar));
 				}
 				
-				if (go_to_file != NULL) {
-					/* the path bar URI will be set to go_to_uri immediately
-					 * in begin_location_change, but we don't want the
-					 * inexistant children to show up anymore */
-					if (slot == slot->pane->active_slot) {
-						/* multiview-TODO also update NautilusWindowSlot
-						 * [which as of writing doesn't save/store any path bar state]
-						 */
-						nautilus_path_bar_clear_buttons (NAUTILUS_PATH_BAR (NAUTILUS_NAVIGATION_WINDOW_PANE (slot->pane)->path_bar));
-					}
-
-					nautilus_window_slot_go_to (slot, go_to_file, FALSE);
-					g_object_unref (go_to_file);
-				} else {
-					nautilus_window_slot_go_home (slot, FALSE);
-				}
+				nautilus_window_slot_go_to (slot, go_to_file, FALSE);
+				g_object_unref (go_to_file);
 			} else {
-				nautilus_window_close (window);
+				nautilus_window_slot_go_home (slot, FALSE);
 			}
                 }
 	} else {
@@ -424,19 +385,16 @@ update_history (NautilusWindowSlot *slot,
         switch (type) {
         case NAUTILUS_LOCATION_CHANGE_STANDARD:
         case NAUTILUS_LOCATION_CHANGE_FALLBACK:
-                nautilus_window_slot_add_current_location_to_history_list (slot);
-                handle_go_elsewhere (slot, new_location);
+		handle_go_elsewhere (slot, new_location);
                 return;
         case NAUTILUS_LOCATION_CHANGE_RELOAD:
                 /* for reload there is no work to do */
                 return;
         case NAUTILUS_LOCATION_CHANGE_BACK:
-                nautilus_window_slot_add_current_location_to_history_list (slot);
-                handle_go_back (NAUTILUS_NAVIGATION_WINDOW_SLOT (slot), new_location);
+                handle_go_back (slot, new_location);
                 return;
         case NAUTILUS_LOCATION_CHANGE_FORWARD:
-                nautilus_window_slot_add_current_location_to_history_list (slot);
-                handle_go_forward (NAUTILUS_NAVIGATION_WINDOW_SLOT (slot), new_location);
+                handle_go_forward (slot, new_location);
                 return;
         case NAUTILUS_LOCATION_CHANGE_REDIRECT:
                 /* for the redirect case, the caller can do the updating */
@@ -461,23 +419,20 @@ cancel_viewed_file_changed_callback (NautilusWindowSlot *slot)
 
 static void
 new_window_show_callback (GtkWidget *widget,
-                          gpointer user_data)
-{
-        NautilusWindow *window;
-        
-        window = NAUTILUS_WINDOW (user_data);
-        
-        nautilus_window_close (window);
+			  gpointer user_data){
+	NautilusWindow *window;
 
-        g_signal_handlers_disconnect_by_func (widget, 
-                                              G_CALLBACK (new_window_show_callback),
-                                              user_data);
+	window = NAUTILUS_WINDOW (user_data);
+	nautilus_window_close (window);
+
+	g_signal_handlers_disconnect_by_func (widget,
+					      G_CALLBACK (new_window_show_callback),
+					      user_data);
 }
 
 void
 nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 					 GFile *location,
-					 NautilusWindowOpenMode mode,
 					 NautilusWindowOpenFlags flags,
 					 GList *new_selection,
 					 NautilusWindowGoToCallback callback,
@@ -488,23 +443,25 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
         NautilusWindowPane *pane;
         NautilusWindowSlot *target_slot;
 	NautilusWindowOpenFlags slot_flags;
-        gboolean existing = FALSE;
 	GFile *old_location;
 	char *old_uri, *new_uri;
 	int new_slot_position;
 	GList *l;
-	gboolean target_spatial, target_navigation, target_same;
+	gboolean use_same;
 	gboolean is_desktop;
+	NautilusApplication *app;
 
 	window = slot->pane->window;
 
         target_window = NULL;
 	target_slot = NULL;
-	target_spatial = target_navigation = target_same = FALSE;
+	use_same = FALSE;
 
+	/* this happens at startup */
 	old_uri = nautilus_window_slot_get_location_uri (slot);
 	if (old_uri == NULL) {
 		old_uri = g_strdup ("(none)");
+		use_same = TRUE;
 	}
 	new_uri = g_file_get_uri (location);
 
@@ -517,86 +474,34 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 		    (flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0));
 
 	is_desktop = NAUTILUS_IS_DESKTOP_WINDOW (window);
-	target_same = is_desktop &&
-		!nautilus_desktop_window_loaded (NAUTILUS_DESKTOP_WINDOW (window));
+
+	/* we use the same window if the preferences say so, but also for the first desktop window */
+	use_same |= g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER) ||
+		(is_desktop && !nautilus_desktop_window_loaded (NAUTILUS_DESKTOP_WINDOW (window)));
+
+	/* and if the flags specify so, this is overridden */
+	if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) != 0) {
+		use_same = FALSE;
+	}
 
 	old_location = nautilus_window_slot_get_location (slot);
 
-	switch (mode) {
-        case NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE :
-		if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
-			/* always use browser: if we're on the desktop the target is a new navigation window,
-			 * otherwise it's the same window.
-			 */
-			if (is_desktop) {
-				target_navigation = TRUE;
-			} else {
-				target_same = TRUE;
-			}
-		} else if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
-			/* don't always use browser: if source is spatial, target is spatial */
-			target_spatial = TRUE;
-		} else if (flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) {
-			/* if it's specified to open a new window, and we're not using spatial,
-			 * the target is a navigation.
-			 */
-			target_navigation = TRUE;
-		}
-                break;
-        case NAUTILUS_WINDOW_OPEN_IN_SPATIAL :
-		target_spatial = TRUE;
-		break;
-        case NAUTILUS_WINDOW_OPEN_IN_NAVIGATION :
-		target_navigation = TRUE;
-                break;
-        default :
-                g_critical ("Unknown open location mode");
-		g_object_unref (old_location);
-                return;
-        }
-
-	/* now get/create the window according to the mode */
-	if (target_same) {
+	/* now get/create the window */
+	if (use_same) {
 		target_window = window;
-	} else if (target_navigation) {
-		target_window = nautilus_application_create_navigation_window
-			(window->application,
+	} else {
+		app = nautilus_application_dup_singleton ();
+		target_window = nautilus_application_create_window
+			(app,
 			 NULL,
 			 gtk_window_get_screen (GTK_WINDOW (window)));
-	} else {
-		target_window = nautilus_application_get_spatial_window
-			(window->application,
-			 window,
-			 NULL,
-			 location,
-			 gtk_window_get_screen (GTK_WINDOW (window)),
-			 &existing);
-	}
-
-	/* if the spatial window is already showing, present it and set the
-	 * new selection, if present.
-	 */
-	if (existing) {
-		target_slot = target_window->details->active_pane->active_slot;
-
-		gtk_window_present (GTK_WINDOW (target_window));
-
-		if (new_selection != NULL && slot->content_view != NULL) {
-			nautilus_view_set_selection (target_slot->content_view, new_selection);
-		}
-
-		/* call the callback successfully */
-		if (callback != NULL) {
-			callback (window, NULL, user_data);
-		}
-
-		return;
+		g_object_unref (app);
 	}
 
         g_assert (target_window != NULL);
 
-	if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0 &&
-	    NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
+	/* if the flags say we want a new tab, open a slot in the current window */
+	if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0) {
 		g_assert (target_window == window);
 
 		slot_flags = 0;
@@ -609,19 +514,20 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 		target_slot = nautilus_window_open_slot (window->details->active_pane, slot_flags);
 	}
 
-        if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND) != 0) {
-                if (NAUTILUS_IS_SPATIAL_WINDOW (window) && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-                        if (gtk_widget_get_visible (GTK_WIDGET (target_window))) {
-                                nautilus_window_close (window);
-                        } else {
-                                g_signal_connect_object (target_window,
-                                                         "show",
-                                                         G_CALLBACK (new_window_show_callback),
-                                                         window,
-                                                         G_CONNECT_AFTER);
-                        }
-                }
-        }
+	/* close the current window if the flags say so */
+	if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND) != 0) {
+		if (!is_desktop) {
+			if (gtk_widget_get_visible (GTK_WIDGET (target_window))) {
+				nautilus_window_close (window);
+			} else {
+				g_signal_connect_object (target_window,
+							 "show",
+							 G_CALLBACK (new_window_show_callback),
+							 window,
+							 G_CONNECT_AFTER);
+			}
+		}
+	}
 
 	if (target_slot == NULL) {
 		if (target_window == window) {
@@ -661,74 +567,6 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 	}
 }
 
-void
-nautilus_window_slot_open_location (NautilusWindowSlot *slot,
-				    GFile *location,
-				    gboolean close_behind)
-{
-	NautilusWindowOpenFlags flags;
-
-	flags = 0;
-	if (close_behind) {
-		flags = NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND;
-	}
-	
-	nautilus_window_slot_open_location_full (slot, location,
-						 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-						 flags, NULL, NULL, NULL);
-}
-
-void
-nautilus_window_slot_open_location_with_selection (NautilusWindowSlot *slot,
-						   GFile *location,
-						   GList *selection,
-						   gboolean close_behind)
-{
-	NautilusWindowOpenFlags flags;
-
-	flags = 0;
-	if (close_behind) {
-		flags = NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND;
-	}
-	nautilus_window_slot_open_location_full (slot, location,
-						 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-						 flags, selection, NULL, NULL);
-}
-
-
-void
-nautilus_window_slot_go_home (NautilusWindowSlot *slot, gboolean new_tab)
-{			      
-	GFile *home;
-	NautilusWindowOpenFlags flags;
-
-	g_return_if_fail (NAUTILUS_IS_WINDOW_SLOT (slot));
-
-	if (new_tab) {
-		flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-	} else {
-		flags = 0;
-	}
-
-	home = g_file_new_for_path (g_get_home_dir ());
-	nautilus_window_slot_open_location_full (slot, home, 
-						 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE, 
-						 flags, NULL, NULL, NULL);
-	g_object_unref (home);
-}
-
-#if 0
-static char *
-nautilus_window_slot_get_view_label (NautilusWindowSlot *slot)
-{
-	const NautilusViewInfo *info;
-
-	info = nautilus_view_factory_lookup (nautilus_window_slot_get_content_view_id (slot));
-
-	return g_strdup (info->label);
-}
-#endif
-
 static char *
 nautilus_window_slot_get_view_error_label (NautilusWindowSlot *slot)
 {
@@ -821,7 +659,7 @@ report_callback (NautilusWindowSlot *slot,
 /*
  * begin_location_change
  * 
- * Change a window's location.
+ * Change a window slot's location.
  * @window: The NautilusWindow whose location should be changed.
  * @location: A url specifying the location to load
  * @new_selection: The initial selection to present after loading the location
@@ -845,7 +683,6 @@ begin_location_change (NautilusWindowSlot *slot,
 		       NautilusWindowGoToCallback callback,
 		       gpointer user_data)
 {
-	NautilusWindow *window;
         NautilusDirectory *directory;
         NautilusFile *file;
 	gboolean force_reload;
@@ -857,10 +694,6 @@ begin_location_change (NautilusWindowSlot *slot,
                   || type == NAUTILUS_LOCATION_CHANGE_FORWARD
                   || distance == 0);
 
-	window = slot->pane->window;
-        g_assert (NAUTILUS_IS_WINDOW (window));
-        g_object_ref (window);
-
 	end_location_change (slot);
 
 	nautilus_window_slot_set_allow_stop (slot, TRUE);
@@ -925,98 +758,6 @@ begin_location_change (NautilusWindowSlot *slot,
 				       NAUTILUS_FILE_ATTRIBUTE_MOUNT,
                                        got_file_info_for_view_selection_callback,
 				       slot);
-
-        g_object_unref (window);
-}
-
-static void
-setup_new_spatial_window (NautilusWindowSlot *slot, NautilusFile *file)
-{
-	NautilusWindow *window;
-	char *show_hidden_file_setting;
-	char *geometry_string;
-	char *scroll_string;
-	gboolean maximized, sticky, above;
-	GtkAction *action;
-
-	window = slot->pane->window;
-
-	if (NAUTILUS_IS_SPATIAL_WINDOW (window) && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		/* load show hidden state */
-		show_hidden_file_setting = nautilus_file_get_metadata 
-			(file, NAUTILUS_METADATA_KEY_WINDOW_SHOW_HIDDEN_FILES,
-			 NULL);
-		if (show_hidden_file_setting != NULL) {
-			if (strcmp (show_hidden_file_setting, "1") == 0) {
-				window->details->show_hidden_files_mode = NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_ENABLE;
-			} else {
-				window->details->show_hidden_files_mode = NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_DISABLE;
-			}
-
-			/* Update the UI, since we initialize it to the default */
-			action = gtk_action_group_get_action (window->details->main_action_group, NAUTILUS_ACTION_SHOW_HIDDEN_FILES);
-			gtk_action_block_activate (action);
-			gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-						      window->details->show_hidden_files_mode == NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_ENABLE);
-			gtk_action_unblock_activate (action);
-		} else {
-			NAUTILUS_WINDOW (window)->details->show_hidden_files_mode = NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_DEFAULT;
-		}
-		g_free (show_hidden_file_setting);
-
-		/* load the saved window geometry */
-		maximized = nautilus_file_get_boolean_metadata
-			(file, NAUTILUS_METADATA_KEY_WINDOW_MAXIMIZED, FALSE);
-		if (maximized) {
-			gtk_window_maximize (GTK_WINDOW (window));
-		} else {
-			gtk_window_unmaximize (GTK_WINDOW (window));
-		}
-
-		sticky = nautilus_file_get_boolean_metadata
-			(file, NAUTILUS_METADATA_KEY_WINDOW_STICKY, FALSE);
-		if (sticky) {
-			gtk_window_stick (GTK_WINDOW (window));
-		} else {
-			gtk_window_unstick (GTK_WINDOW (window));
-		}
-
-		above = nautilus_file_get_boolean_metadata
-			(file, NAUTILUS_METADATA_KEY_WINDOW_KEEP_ABOVE, FALSE);
-		if (above) {
-			gtk_window_set_keep_above (GTK_WINDOW (window), TRUE);
-		} else {
-			gtk_window_set_keep_above (GTK_WINDOW (window), FALSE);
-		}
-
-		geometry_string = nautilus_file_get_metadata 
-			(file, NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY, NULL);
-                if (geometry_string != NULL) {
-                        eel_gtk_window_set_initial_geometry_from_string 
-                                (GTK_WINDOW (window), 
-                                 geometry_string,
-                                 NAUTILUS_SPATIAL_WINDOW_MIN_WIDTH, 
-                                 NAUTILUS_SPATIAL_WINDOW_MIN_HEIGHT,
-				 FALSE);
-                }
-                g_free (geometry_string);
-
-		if (slot->pending_selection == NULL) {
-			/* If there is no pending selection, then load the saved scroll position. */
-			scroll_string = nautilus_file_get_metadata 
-				(file, NAUTILUS_METADATA_KEY_WINDOW_SCROLL_POSITION,
-				 NULL);
-		} else {
-			/* If there is a pending selection, we want to scroll to an item in
-			 * the pending selection list. */
-			scroll_string = g_file_get_uri (slot->pending_selection->data);
-		}
-
-		/* scroll_string might be NULL if there was no saved scroll position. */
-		if (scroll_string != NULL) {
-			slot->pending_scroll_to = scroll_string;
-		}
-        }
 }
 
 typedef struct {
@@ -1030,14 +771,12 @@ mount_not_mounted_callback (GObject *source_object,
 			    gpointer user_data)
 {
 	MountNotMountedData *data;
-	NautilusWindow *window;
 	NautilusWindowSlot *slot;
 	GError *error;
 	GCancellable *cancellable;
 
 	data = user_data;
 	slot = data->slot;
-	window = slot->pane->window;
 	cancellable = data->cancellable;
 	g_free (data);
 
@@ -1161,10 +900,6 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	}
 
 	if (view_id != NULL) {
-                if (!gtk_widget_get_visible (GTK_WIDGET (window)) && NAUTILUS_IS_SPATIAL_WINDOW (window)) {
-			/* We now have the metadata to set up the window position, etc */
-			setup_new_spatial_window (slot, file);
-		}
 		create_content_view (slot, view_id);
 		g_free (view_id);
 
@@ -1221,7 +956,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 			/* We're missing a previous location (if opened location
 			 * in a new tab) so close it and return */
 			if (slot->location == NULL) {
-				nautilus_window_slot_close (slot);
+				nautilus_window_pane_slot_close (slot->pane, slot);
 			} else {
 				/* We disconnected this, so we need to re-connect it */
 				viewed_file = nautilus_file_get (slot->location);
@@ -1281,14 +1016,13 @@ create_content_view (NautilusWindowSlot *slot,
         	g_object_ref (view);
         } else {
                 /* create a new content view */
-		view = nautilus_view_factory_create (view_id,
-						     NAUTILUS_WINDOW_SLOT_INFO (slot));
+		view = nautilus_view_factory_create (view_id, slot);
 
                 eel_accessibility_set_name (view, _("Content View"));
                 eel_accessibility_set_description (view, _("View of the current folder"));
 
                 slot->new_content_view = view;
-		nautilus_window_slot_connect_content_view (slot, slot->new_content_view);
+		nautilus_window_connect_content_view (window, slot->new_content_view);
         }
 
 	/* Actually load the pending location and selection: */
@@ -1328,7 +1062,6 @@ load_new_location (NautilusWindowSlot *slot,
 	NautilusWindow *window;
 	GList *selection_copy;
 	NautilusView *view;
-	char *uri;
 
 	g_assert (slot != NULL);
 	g_assert (location != NULL);
@@ -1343,18 +1076,14 @@ load_new_location (NautilusWindowSlot *slot,
 	/* Note, these may recurse into report_load_underway */
         if (slot->content_view != NULL && tell_current_content_view) {
 		view = slot->content_view;
-		uri = g_file_get_uri (location);
-		nautilus_view_load_location (slot->content_view, uri);
-		g_free (uri);
+		nautilus_view_load_location (slot->content_view, location);
         }
 	
         if (slot->new_content_view != NULL && tell_new_content_view &&
 	    (!tell_current_content_view ||
 	     slot->new_content_view != slot->content_view) ) {
 		view = slot->new_content_view;
-		uri = g_file_get_uri (location);
-		nautilus_view_load_location (slot->new_content_view, uri);
-		g_free (uri);
+		nautilus_view_load_location (slot->new_content_view, location);
         }
 	if (view != NULL) {
 		/* slot->new_content_view might have changed here if
@@ -1446,9 +1175,6 @@ location_has_really_changed (NautilusWindowSlot *slot)
 		widget = nautilus_view_get_widget (slot->new_content_view);
 		/* Switch to the new content view. */
 		if (gtk_widget_get_parent (widget) == NULL) {
-			if (slot->content_view != NULL) {
-				nautilus_window_slot_disconnect_content_view (slot, slot->content_view);
-			}
 			nautilus_window_slot_set_content_view_widget (slot, slot->new_content_view);
 		}
 		g_object_unref (slot->new_content_view);
@@ -1533,12 +1259,13 @@ nautilus_window_slot_show_x_content_bar (NautilusWindowSlot *slot, GMount *mount
 }
 
 static void
-nautilus_window_slot_show_trash_bar (NautilusWindowSlot *slot,
-				     NautilusWindow *window)
+nautilus_window_slot_show_trash_bar (NautilusWindowSlot *slot)
 {
 	GtkWidget *bar;
+	NautilusView *view;
 
-	bar = nautilus_trash_bar_new (window);
+	view = nautilus_window_slot_get_current_view (slot);
+	bar = nautilus_trash_bar_new (view);
 	gtk_widget_show (bar);
 
 	nautilus_window_slot_add_extra_location_widget (slot, bar);
@@ -1582,14 +1309,11 @@ found_mount_cb (GObject *source_object,
 {
 	FindMountData *data = user_data;
 	GMount *mount;
-	NautilusWindowSlot *slot;
 
 	if (g_cancellable_is_cancelled (data->cancellable)) {
 		goto out;
 	}
 
-	slot = data->slot;
-	
 	mount = g_file_find_enclosing_mount_finish (G_FILE (source_object),
 						    res,
 						    NULL);
@@ -1673,7 +1397,7 @@ update_for_new_location (NautilusWindowSlot *slot)
 		nautilus_window_slot_update_query_editor (slot);
 
 		if (nautilus_directory_is_in_trash (directory)) {
-			nautilus_window_slot_show_trash_bar (slot, window);
+			nautilus_window_slot_show_trash_bar (slot);
 		}
 
 		/* need the mount to determine if we should put up the x-content cluebar */
@@ -1708,11 +1432,6 @@ update_for_new_location (NautilusWindowSlot *slot)
 		if (location_really_changed) {
 			nautilus_window_pane_sync_search_widgets (slot->pane);
 		}
-
-		if (NAUTILUS_IS_NAVIGATION_WINDOW (window) &&
-		    slot->pane == window->details->active_pane) {
-			nautilus_navigation_window_load_extension_toolbar_items (NAUTILUS_NAVIGATION_WINDOW (window));
-		}
 	}
 }
 
@@ -1747,11 +1466,8 @@ nautilus_window_report_load_complete (NautilusWindow *window,
 static void
 end_location_change (NautilusWindowSlot *slot)
 {
-	NautilusWindow *window;
 	char *uri;
 
-	window = slot->pane->window;
-
 	uri = nautilus_window_slot_get_location_uri (slot);
 	if (uri) {
 		DEBUG ("Finished loading window for uri %s", uri);
@@ -1806,7 +1522,7 @@ free_location_change (NautilusWindowSlot *slot)
 		nautilus_view_stop_loading (slot->new_content_view);
 		window->details->temporarily_ignore_view_signals = FALSE;
 
-		nautilus_window_slot_disconnect_content_view (slot, slot->new_content_view);
+		nautilus_window_disconnect_content_view (window, slot->new_content_view);
         	g_object_unref (slot->new_content_view);
                 slot->new_content_view = NULL;
         }
@@ -1859,7 +1575,6 @@ nautilus_window_report_view_failed (NautilusWindow *window,
 	fallback_load_location = NULL;
 	
 	if (view == slot->content_view) {
-		nautilus_window_slot_disconnect_content_view (slot, view);
                 nautilus_window_slot_set_content_view_widget (slot, NULL);
 
                 report_current_content_view_failure_to_user (slot);
@@ -1899,7 +1614,6 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 	char *error_message;
 	char *detail_message;
 	char *scheme_string;
-	GtkDialog *dialog;
 
 	/* Some sort of failure occurred. How 'bout we tell the user? */
 	full_uri_for_display = g_file_get_parse_name (location);
@@ -1987,8 +1701,8 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		detail_message = g_strdup_printf (_("Error: %s\nPlease select another viewer and try again."), error->message);
 	}
 	
-	dialog = eel_show_error_dialog (error_message, detail_message, NULL);
-	
+	eel_show_error_dialog (error_message, detail_message, NULL);
+
 	g_free (uri_for_display);
 	g_free (error_message);
 	g_free (detail_message);
@@ -2061,7 +1775,7 @@ nautilus_window_manage_views_close_slot (NautilusWindowPane *pane,
 					 NautilusWindowSlot *slot)
 {
 	if (slot->content_view != NULL) {
-		nautilus_window_slot_disconnect_content_view (slot, slot->content_view);
+		nautilus_window_disconnect_content_view (slot->pane->window, slot->content_view);
 	}
 
 	free_location_change (slot);
@@ -2069,19 +1783,19 @@ nautilus_window_manage_views_close_slot (NautilusWindowPane *pane,
 }
 
 void
-nautilus_navigation_window_back_or_forward (NautilusNavigationWindow *window, 
-                                            gboolean back, guint distance, gboolean new_tab)
+nautilus_window_back_or_forward (NautilusWindow *window, 
+				 gboolean back,
+				 guint distance,
+				 gboolean new_tab)
 {
 	NautilusWindowSlot *slot;
-	NautilusNavigationWindowSlot *navigation_slot;
 	GList *list;
 	GFile *location;
         guint len;
         NautilusBookmark *bookmark;
 
-	slot = NAUTILUS_WINDOW (window)->details->active_pane->active_slot;
-	navigation_slot = (NautilusNavigationWindowSlot *) slot;
-	list = back ? navigation_slot->back_list : navigation_slot->forward_list;
+	slot = window->details->active_pane->active_slot;
+	list = back ? slot->back_list : slot->forward_list;
 
         len = (guint) g_list_length (list);
 
@@ -2099,7 +1813,6 @@ nautilus_navigation_window_back_or_forward (NautilusNavigationWindow *window,
 
 	if (new_tab) {
 		nautilus_window_slot_open_location_full (slot, location,
-							 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
 							 NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB,
 							 NULL, NULL, NULL);
 	} else {
@@ -2152,12 +1865,3 @@ nautilus_window_slot_reload (NautilusWindowSlot *slot)
 	g_object_unref (location);
 	g_list_free_full (selection, g_object_unref);
 }
-
-void
-nautilus_window_reload (NautilusWindow *window)
-{
-	g_assert (NAUTILUS_IS_WINDOW (window));
-
-	nautilus_window_slot_reload (window->details->active_pane->active_slot);
-}
-
